Logo
----
Logo extracted by:


    wget https://singularity-uk.com/Downloads-for-customers/art-net_master_logo.zip
    unzip art-net_master_logo.zip 
    epstopdf Art-Net\ Master\ Logo.eps 
    pdf2svg Art-Net\ Master\ Logo.pdf art-net-master-logo.svg
    rm Art-Net\ Master\ Logo.*
    rm *.zip

